@@ -140,7 +140,7 @@ class CSVKitUtility(object):
         # Input
         if 'f' not in self.override_flags:
             self.argparser.add_argument(metavar='FILE', nargs='?', dest='input_path',
-                                        help='The CSV file to operate on. If omitted, will accept input on STDIN.')
+                                        help='The CSV file to operate on. If omitted, will accept input as piped data via STDIN.')
         if 'd' not in self.override_flags:
             self.argparser.add_argument('-d', '--delimiter', dest='delimiter',
                                         help='Delimiting character of the input CSV file.')
@@ -163,7 +163,7 @@ class CSVKitUtility(object):
             self.argparser.add_argument('-z', '--maxfieldsize', dest='field_size_limit', type=int,
                                         help='Maximum length of a single field in the input CSV file.')
         if 'e' not in self.override_flags:
-            self.argparser.add_argument('-e', '--encoding', dest='encoding', default='utf-8',
+            self.argparser.add_argument('-e', '--encoding', dest='encoding', default='utf-8-sig',
                                         help='Specify the encoding of the input CSV file.')
         if 'L' not in self.override_flags:
             self.argparser.add_argument('-L', '--locale', dest='locale', default='en_US',
@@ -185,7 +185,7 @@ class CSVKitUtility(object):
                                         help='Specify that the input CSV file has no header row. Will create default headers (a,b,c,...).')
         if 'K' not in self.override_flags:
             self.argparser.add_argument('-K', '--skip-lines', dest='skip_lines', type=int, default=0,
-                                        help='Specify the number of initial lines to skip (e.g. comments, copyright notices, empty rows).')
+                                        help='Specify the number of initial lines to skip before the header row (e.g. comments, copyright notices, empty rows).')
         if 'v' not in self.override_flags:
             self.argparser.add_argument('-v', '--verbose', dest='verbose', action='store_true',
                                         help='Print detailed tracebacks when errors occur.')
@@ -200,7 +200,7 @@ class CSVKitUtility(object):
             self.argparser.add_argument('--zero', dest='zero_based', action='store_true',
                                         help='When interpreting or displaying column numbers, use zero-based numbering instead of the default 1-based numbering.')
 
-        self.argparser.add_argument('-V', '--version', action='version', version='%(prog)s 1.0.3',
+        self.argparser.add_argument('-V', '--version', action='version', version='%(prog)s 1.0.5',
                                     help='Display version information and exit.')
 
     def _open_input_file(self, path):
@@ -284,7 +284,7 @@ class CSVKitUtility(object):
                                      'flag or with the PYTHONIOENCODING environment variable. Use the -v flag to see '
                                      'the complete error.\n' % self.args.encoding)
                 else:
-                    sys.stderr.write('%s\n' % six.text_type(value))
+                    sys.stderr.write('%s: %s\n' % (t.__name__, six.text_type(value)))
 
         sys.excepthook = handler
 
@@ -294,16 +294,27 @@ class CSVKitUtility(object):
         else:
             type_kwargs = {}
 
-        types = [agate.Text(**type_kwargs)]
+        text_type = agate.Text(**type_kwargs)
 
-        if not self.args.no_inference:
+        if self.args.no_inference:
+            types = [text_type]
+        else:
+            number_type = agate.Number(locale=self.args.locale, **type_kwargs)
+
+            # See the order in the `agate.TypeTester` class.
             types = [
                 agate.Boolean(**type_kwargs),
-                agate.Number(locale=self.args.locale, **type_kwargs),
                 agate.TimeDelta(**type_kwargs),
                 agate.Date(date_format=self.args.date_format, **type_kwargs),
                 agate.DateTime(datetime_format=self.args.datetime_format, **type_kwargs),
-            ] + types
+                text_type,
+            ]
+
+            # In order to parse dates like "20010101".
+            if self.args.date_format or self.args.datetime_format:
+                types.insert(-1, number_type)
+            else:
+                types.insert(1, number_type)
 
         return agate.TypeTester(types=types)
 
@@ -354,19 +365,16 @@ class CSVKitUtility(object):
         if getattr(self.args, 'no_header_row', None):
             raise RequiredHeaderError('You cannot use --no-header-row with the -n or --names options.')
 
-        f = self.input_file
-        output = self.output_file
-
         if getattr(self.args, 'zero_based', None):
             start = 0
         else:
             start = 1
 
-        rows = agate.csv.reader(f, **self.reader_kwargs)
+        rows = agate.csv.reader(self.skip_lines(), **self.reader_kwargs)
         column_names = next(rows)
 
         for i, c in enumerate(column_names, start):
-            output.write('%3i: %s\n' % (i, c))
+            self.output_file.write('%3i: %s\n' % (i, c))
 
     def additional_input_expected(self):
         return sys.stdin.isatty() and not self.args.input_path
@@ -396,11 +404,11 @@ def match_column_identifier(column_names, c, column_offset=1):
 
         # Fail out if index is 0-based
         if c < 0:
-            raise ColumnIdentifierError("Column 0 is invalid. Columns are 1-based.")
+            raise ColumnIdentifierError("Column %i is invalid. Columns are 1-based." % (c + column_offset))
 
         # Fail out if index is out of range
         if c >= len(column_names):
-            raise ColumnIdentifierError("Column %i is invalid. The last column is '%s' at index %i." % (c, column_names[-1], len(column_names) - 1))
+            raise ColumnIdentifierError("Column %i is invalid. The last column is '%s' at index %i." % (c + column_offset, column_names[-1], len(column_names) - 1 + column_offset))
 
     return c
 
