@@ -46,7 +46,7 @@ class CSVCut(CSVKitUtility):
         for row in rows:
             out_row = [row[column_id] if column_id < len(row) else None for column_id in column_ids]
 
-            if not self.args.delete_empty or ''.join(out_row):
+            if not self.args.delete_empty or any(out_row):
                 output.writerow(out_row)
 
 
