@@ -20,7 +20,7 @@ class CSVSQL(CSVKitUtility):
 
     def add_arguments(self):
         self.argparser.add_argument(metavar='FILE', nargs='*', dest='input_paths', default=['-'],
-                                    help='The CSV file(s) to operate on. If omitted, will accept input on STDIN.')
+                                    help='The CSV file(s) to operate on. If omitted, will accept input as piped data via STDIN.')
         self.argparser.add_argument('-i', '--dialect', dest='dialect', choices=DIALECTS,
                                     help='Dialect of SQL to generate. Only valid when --db is not specified.')
         self.argparser.add_argument('--db', dest='connection_string',
@@ -46,13 +46,15 @@ class CSVSQL(CSVKitUtility):
         self.argparser.add_argument('--create-if-not-exists', dest='create_if_not_exists', action='store_true',
                                     help='Create table if it does not exist, otherwise keep going. Only valid when --insert is specified.')
         self.argparser.add_argument('--overwrite', dest='overwrite', action='store_true',
-                                    help='Drop the table before creating. Only valid when --insert is specified.')
+                                    help='Drop the table before creating. Only valid when --insert is specified and --no-create is not specified.')
         self.argparser.add_argument('--db-schema', dest='db_schema',
                                     help='Optional name of database schema to create table(s) in.')
         self.argparser.add_argument('-y', '--snifflimit', dest='sniff_limit', type=int,
                                     help='Limit CSV dialect sniffing to the specified number of bytes. Specify "0" to disable sniffing entirely.')
         self.argparser.add_argument('-I', '--no-inference', dest='no_inference', action='store_true',
                                     help='Disable type inference when parsing the input.')
+        self.argparser.add_argument('--chunk-size', dest='chunk_size', type=int,
+                                    help='Chunk size for batch insert into the table. Only valid when --insert is specified.')
 
     def main(self):
         if sys.stdin.isatty() and not self.args.input_paths:
@@ -84,10 +86,14 @@ class CSVSQL(CSVKitUtility):
             self.argparser.error('The --create-if-not-exists option is only valid if --insert is also specified.')
         if self.args.overwrite and not self.args.insert:
             self.argparser.error('The --overwrite option is only valid if --insert is also specified.')
+        if self.args.overwrite and self.args.no_create:
+            self.argparser.error('The --overwrite option is only valid if --no-create is not specified.')
         if self.args.before_insert and not self.args.insert:
-            self.argparser.error('The --before_insert option is only valid if --insert is also specified.')
+            self.argparser.error('The --before-insert option is only valid if --insert is also specified.')
         if self.args.after_insert and not self.args.insert:
-            self.argparser.error('The --after_insert option is only valid if --insert is also specified.')
+            self.argparser.error('The --after-insert option is only valid if --insert is also specified.')
+        if self.args.chunk_size and not self.args.insert:
+            self.argparser.error('The --chunk-size option is only valid if --insert is also specified.')
 
         if self.args.no_create and self.args.create_if_not_exists:
             self.argparser.error('The --no-create and --create-if-not-exists options are mutually exclusive.')
@@ -101,7 +107,7 @@ class CSVSQL(CSVKitUtility):
             try:
                 engine = create_engine(self.args.connection_string)
             except ImportError:
-                raise ImportError('You don\'t appear to have the necessary database backend installed for connection string you\'re trying to use. Available backends include:\n\nPostgresql:\tpip install psycopg2\nMySQL:\t\tpip install MySQL-python\n\nFor details on connection strings and other backends, please see the SQLAlchemy documentation on dialects at: \n\nhttp://www.sqlalchemy.org/docs/dialects/\n\n')
+                raise ImportError('You don\'t appear to have the necessary database backend installed for connection string you\'re trying to use. Available backends include:\n\nPostgresql:\tpip install psycopg2\nMySQL:\t\tpip install mysql-connector-python\n\nFor details on connection strings and other backends, please see the SQLAlchemy documentation on dialects at: \n\nhttp://www.sqlalchemy.org/docs/dialects/\n\n')
 
             self.connection = engine.connect()
 
@@ -164,7 +170,8 @@ class CSVSQL(CSVKitUtility):
                         prefixes=self.args.prefix,
                         db_schema=self.args.db_schema,
                         constraints=not self.args.no_constraints,
-                        unique_constraint=self.unique_constraint
+                        unique_constraint=self.unique_constraint,
+                        chunk_size=self.args.chunk_size
                     )
 
                     if self.args.after_insert:
@@ -200,10 +207,11 @@ class CSVSQL(CSVKitUtility):
                         rows = self.connection.execute(q)
 
                 # Output the result of the last query as CSV
-                output = agate.csv.writer(self.output_file, **self.writer_kwargs)
-                output.writerow(rows._metadata.keys)
-                for row in rows:
-                    output.writerow(row)
+                if rows.returns_rows:
+                    output = agate.csv.writer(self.output_file, **self.writer_kwargs)
+                    output.writerow(rows._metadata.keys)
+                    for row in rows:
+                        output.writerow(row)
 
             transaction.commit()
 
