@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 
 import os.path
+import sys
 
 import agate
 
@@ -8,13 +9,13 @@ from csvkit.cli import CSVKitUtility, make_default_headers
 
 
 class CSVStack(CSVKitUtility):
-    description = 'Stack up the rows from multiple CSV files, optionally adding a grouping value.'
+    description = 'Stack up the rows from multiple CSV files, optionally adding a grouping value. Files are assumed to have the same columns in the same order.'
     # Override 'f' because the utility accepts multiple files.
     override_flags = ['f', 'L', 'blanks', 'date-format', 'datetime-format']
 
     def add_arguments(self):
-        self.argparser.add_argument(metavar="FILE", nargs='+', dest='input_paths', default=['-'],
-                                    help='The CSV file(s) to operate on. If omitted, will accept input on STDIN.')
+        self.argparser.add_argument(metavar='FILE', nargs='*', dest='input_paths', default=['-'],
+                                    help='The CSV file(s) to operate on. If omitted, will accept input as piped data via STDIN.')
         self.argparser.add_argument('-g', '--groups', dest='groups',
                                     help='A comma-separated list of values to add as "grouping factors", one for each CSV being stacked. These will be added to the stacked CSV as a new column. You may specify a name for the grouping column using the -n flag.')
         self.argparser.add_argument('-n', '--group-name', dest='group_name',
@@ -23,20 +24,15 @@ class CSVStack(CSVKitUtility):
                                     help='Use the filename of each input file as its grouping value. When specified, -g will be ignored.')
 
     def main(self):
-        self.input_files = []
+        if sys.stdin.isatty() and not self.args.input_paths:
+            sys.stderr.write('No input file or piped data provided. Waiting for standard input:\n')
 
-        for path in self.args.input_paths:
-            self.input_files.append(self._open_input_file(path))
+        has_groups = self.args.groups is not None or self.args.group_by_filenames
 
-        if not self.input_files:
-            self.argparser.error('You must specify at least one file to stack.')
-
-        if self.args.group_by_filenames:
-            groups = [os.path.basename(f.name) for f in self.input_files]
-        elif self.args.groups:
+        if self.args.groups is not None and not self.args.group_by_filenames:
             groups = self.args.groups.split(',')
 
-            if len(groups) != len(self.input_files):
+            if len(groups) != len(self.args.input_paths):
                 self.argparser.error('The number of grouping values must be equal to the number of CSV files being stacked.')
         else:
             groups = None
@@ -45,7 +41,9 @@ class CSVStack(CSVKitUtility):
 
         output = agate.csv.writer(self.output_file, **self.writer_kwargs)
 
-        for i, f in enumerate(self.input_files):
+        for i, path in enumerate(self.args.input_paths):
+            f = self._open_input_file(path)
+
             if isinstance(self.args.skip_lines, int):
                 skip_lines = self.args.skip_lines
                 while skip_lines > 0:
@@ -56,12 +54,18 @@ class CSVStack(CSVKitUtility):
 
             rows = agate.csv.reader(f, **self.reader_kwargs)
 
+            if has_groups:
+                if groups:
+                    group = groups[i]
+                else:
+                    group = os.path.basename(f.name)
+
             # If we have header rows, use them
             if not self.args.no_header_row:
                 headers = next(rows, [])
 
                 if i == 0:
-                    if groups:
+                    if has_groups:
                         headers.insert(0, group_name)
 
                     output.writerow(headers)
@@ -72,19 +76,19 @@ class CSVStack(CSVKitUtility):
                 headers = make_default_headers(len(row))
 
                 if i == 0:
-                    if groups:
+                    if has_groups:
                         headers.insert(0, group_name)
 
                     output.writerow(headers)
 
-                if groups:
-                    row.insert(0, groups[i])
+                if has_groups:
+                    row.insert(0, group)
 
                 output.writerow(row)
 
             for row in rows:
-                if groups:
-                    row.insert(0, groups[i])
+                if has_groups:
+                    row.insert(0, group)
 
                 output.writerow(row)
 
