@@ -33,7 +33,7 @@ class In2CSV(CSVKitUtility):
                 return bytestring
 
         self.argparser.add_argument(metavar='FILE', nargs='?', dest='input_path',
-                                    help='The CSV file to operate on. If omitted, will accept input on STDIN.')
+                                    help='The CSV file to operate on. If omitted, will accept input as piped data via STDIN.')
         self.argparser.add_argument('-f', '--format', dest='filetype',
                                     help='The format of the input file. If not specified will be inferred from the file type. Supported formats: %s.' % ', '.join(sorted(SUPPORTED_FORMATS)))
         self.argparser.add_argument('-s', '--schema', dest='schema',
@@ -62,11 +62,14 @@ class In2CSV(CSVKitUtility):
         else:
             return open(path, 'rb')
 
-    def sheet_names(self, filetype):
+    def sheet_names(self, path, filetype):
+        input_file = self.open_excel_input_file(path)
         if filetype == 'xls':
-            return xlrd.open_workbook(file_contents=self.input_file.read()).sheet_names()
-        elif filetype == 'xlsx':
-            return openpyxl.load_workbook(self.input_file, read_only=True, data_only=True).sheetnames
+            sheet_names = xlrd.open_workbook(file_contents=input_file.read()).sheet_names()
+        else:  # 'xlsx'
+            sheet_names = openpyxl.load_workbook(input_file, read_only=True, data_only=True).sheetnames
+        input_file.close()
+        return sheet_names
 
     def main(self):
         path = self.args.input_path
@@ -82,27 +85,26 @@ class In2CSV(CSVKitUtility):
             filetype = 'json'
         else:
             if not path or path == '-':
-                self.argparser.error('You must specify a format when providing data via STDIN (pipe).')
+                self.argparser.error('You must specify a format when providing input as piped data via STDIN.')
             filetype = convert.guess_format(path)
             if not filetype:
                 self.argparser.error('Unable to automatically determine the format of the input file. Try specifying a format with --format.')
 
+        if self.args.names_only:
+            if filetype in ('xls', 'xlsx'):
+                sheets = self.sheet_names(path, filetype)
+                for sheet in sheets:
+                    self.output_file.write('%s\n' % sheet)
+            else:
+                self.argparser.error('You cannot use the -n or --names options with non-Excel files.')
+            return
+
         # Set the input file.
         if filetype in ('xls', 'xlsx'):
             self.input_file = self.open_excel_input_file(path)
         else:
             self.input_file = self._open_input_file(path)
 
-        if self.args.names_only:
-            sheets = self.sheet_names(filetype)
-            if sheets:
-                for sheet in sheets:
-                    self.output_file.write('%s\n' % sheet)
-            else:
-                self.argparser.error('You cannot use the -n or --names options with non-Excel files.')
-            self.input_file.close()
-            return
-
         # Set the reader's arguments.
         kwargs = {}
 
@@ -148,7 +150,7 @@ class In2CSV(CSVKitUtility):
                 if not hasattr(self.input_file, 'name'):
                     raise ValueError('DBF files can not be converted from stdin. You must pass a filename.')
                 table = agate.Table.from_dbf(self.input_file.name, **kwargs)
-            table.to_csv(self.output_file)
+            table.to_csv(self.output_file, **self.writer_kwargs)
 
         if self.args.write_sheets:
             # Close and re-open the file, as the file object has been mutated or closed.
@@ -157,19 +159,19 @@ class In2CSV(CSVKitUtility):
             self.input_file = self.open_excel_input_file(path)
 
             if self.args.write_sheets == '-':
-                sheets = self.sheet_names(filetype)
+                sheets = self.sheet_names(path, filetype)
             else:
                 sheets = [int(sheet) if sheet.isdigit() else sheet for sheet in self.args.write_sheets.split(',')]
 
             if filetype == 'xls':
-                tables = agate.Table.from_xls(self.input_file, sheet=sheets, **kwargs)
+                tables = agate.Table.from_xls(self.input_file, sheet=sheets, encoding_override=self.args.encoding_xls, **kwargs)
             elif filetype == 'xlsx':
                 tables = agate.Table.from_xlsx(self.input_file, sheet=sheets, **kwargs)
 
             base = splitext(self.input_file.name)[0]
             for i, table in enumerate(tables.values()):
                 with open('%s_%d.csv' % (base, i), 'w') as f:
-                    table.to_csv(f)
+                    table.to_csv(f, **self.writer_kwargs)
 
         self.input_file.close()
 
