@@ -1,11 +1,7 @@
 #!/usr/bin/env python
 
 import re
-
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
+import unittest
 
 from csvkit.grep import FilteringCSVReader
 from csvkit.exceptions import ColumnIdentifierError
