@@ -62,6 +62,12 @@ class TestCSVCut(CSVKitTestCase, ColumnsTests, EmptyFileTests, NamesTests):
             ['1'],
         ])
 
+    def test_delete_empty(self):
+        self.assertRows(['-c', 'column_c', '--delete-empty-rows', 'examples/bad.csv'], [
+            ['column_c'],
+            ['17'],
+        ])
+
     def test_no_header_row(self):
         self.assertRows(['-c', '2', '--no-header-row', 'examples/no_header_row.csv'], [
             ['b'],
@@ -71,3 +77,17 @@ class TestCSVCut(CSVKitTestCase, ColumnsTests, EmptyFileTests, NamesTests):
     def test_ragged(self):
         # Test that csvcut doesn't error when a row is short.
         self.get_output(['-c', 'column_c', 'examples/bad.csv'])
+
+    def test_truncate(self):
+        # Test that csvcut truncates long rows.
+        self.assertRows(['-C', 'column_a,column_b', '--delete-empty-rows', 'examples/bad.csv'], [
+            ['column_c'],
+            ['17'],
+        ])
+
+    def test_names_with_skip_lines(self):
+        self.assertLines(['--names', '--skip-lines', '3', 'examples/test_skip_lines.csv'], [
+            '  1: a',
+            '  2: b',
+            '  3: c',
+        ])
