@@ -22,10 +22,26 @@ class TestCSVLook(CSVKitTestCase, EmptyFileTests):
             launch_new_instance()
 
     def test_runs(self):
-        self.get_output(['examples/test_utf8.csv'])
+        if sys.version_info < (3,):
+            self.get_output(['examples/test_utf8.csv'])
+        else:
+            self.assertLines(['examples/test_utf8.csv'], [
+                '| foo | bar | baz |',
+                '| --- | --- | --- |',
+                '|   1 |   2 | 3   |',
+                '|   4 |   5 | ʤ   |',
+            ])
 
     def test_encoding(self):
-        self.get_output(['-e', 'latin1', 'examples/test_latin1.csv'])
+        if sys.version_info < (3,):
+            self.get_output(['-e', 'latin1', 'examples/test_latin1.csv'])
+        else:
+            self.assertLines(['-e', 'latin1', 'examples/test_latin1.csv'], [
+                '| a | b | c |',
+                '| - | - | - |',
+                '| 1 | 2 | 3 |',
+                '| 4 | 5 | © |',
+            ])
 
     def test_simple(self):
         self.assertLines(['examples/dummy3.csv'], [
@@ -65,6 +81,14 @@ class TestCSVLook(CSVKitTestCase, EmptyFileTests):
             u'|   4 |   5 | ʤ   |',
         ])
 
+    def test_unicode_bom(self):
+        self.assertLines(['examples/test_utf8_bom.csv'], [
+            '| foo | bar | baz |',
+            '| --- | --- | --- |',
+            '|   1 |   2 | 3   |',
+            u'|   4 |   5 | ʤ   |',
+        ])
+
     def test_linenumbers(self):
         self.assertLines(['--linenumbers', 'examples/dummy3.csv'], [
             '| line_numbers |    a | b | c |',
