@@ -22,10 +22,24 @@ class TestCSVSort(CSVKitTestCase, ColumnsTests, EmptyFileTests, NamesTests):
             launch_new_instance()
 
     def test_runs(self):
-        self.get_output(['examples/test_utf8.csv'])
+        if sys.version_info < (3,):
+            self.get_output(['examples/test_utf8.csv'])
+        else:
+            self.assertRows(['examples/test_utf8.csv'], [
+                ['foo', 'bar', 'baz'],
+                ['1', '2', '3'],
+                ['4', '5', 'ʤ'],
+            ])
 
     def test_encoding(self):
-        self.get_output(['-e', 'latin1', 'examples/test_latin1.csv'])
+        if sys.version_info < (3,):
+            self.get_output(['-e', 'latin1', 'examples/test_latin1.csv'])
+        else:
+            self.assertRows(['-e', 'latin1', 'examples/test_latin1.csv'], [
+                ['a', 'b', 'c'],
+                ['1', '2', '3'],
+                ['4', '5', '©'],
+            ])
 
     def test_sort_string_reverse(self):
         reader = self.get_output_as_reader(['-c', '1', '-r', 'examples/testxls_converted.csv'])
@@ -40,9 +54,6 @@ class TestCSVSort(CSVKitTestCase, ColumnsTests, EmptyFileTests, NamesTests):
         self.assertEqual(test_order, new_order)
 
     def test_no_blanks(self):
-        pass
-
-    def test_blanks(self):
         reader = self.get_output_as_reader(['examples/blanks.csv'])
         test_order = [
             ['a', 'b', 'c', 'd', 'e', 'f'],
@@ -51,7 +62,7 @@ class TestCSVSort(CSVKitTestCase, ColumnsTests, EmptyFileTests, NamesTests):
         new_order = [r for r in reader]
         self.assertEqual(test_order, new_order)
 
-    def test_no_header_row(self):
+    def test_blanks(self):
         reader = self.get_output_as_reader(['--blanks', 'examples/blanks.csv'])
         test_order = [
             ['a', 'b', 'c', 'd', 'e', 'f'],
@@ -60,6 +71,12 @@ class TestCSVSort(CSVKitTestCase, ColumnsTests, EmptyFileTests, NamesTests):
         new_order = [r for r in reader]
         self.assertEqual(test_order, new_order)
 
+    def test_no_header_row(self):
+        self.assertRows(['--no-header-row', '--no-inference', 'examples/no_header_row.csv'], [
+            ['a', 'b', 'c'],
+            ['1', '2', '3'],
+        ])
+
     def test_no_inference(self):
         reader = self.get_output_as_reader(['--no-inference', '-c', '1', 'examples/test_literal_order.csv'])
         test_order = [u'a', u'192', u'27', u'3']
