@@ -176,6 +176,11 @@ class TestCSVSQL(CSVKitTestCase, EmptyFileTests):
             "question,text\n"
             "36,©\n")
 
+    def test_query_update(self):
+        sql = self.get_output(['--query', 'UPDATE dummy SET a=10 WHERE a=1', '--no-inference', 'examples/dummy.csv'])
+
+        self.assertEqual(sql, '')
+
     def test_before_after_insert(self):
         self.get_output(['--db', 'sqlite:///' + self.db_file, '--insert', 'examples/dummy.csv', '--before-insert',
                          'SELECT 1; CREATE TABLE foobar (date DATE)', '--after-insert', 'INSERT INTO dummy VALUES (0, 5, 6)'])
@@ -192,7 +197,7 @@ class TestCSVSQL(CSVKitTestCase, EmptyFileTests):
         utility.run()
         output = output_file.getvalue()
         output_file.close()
-        self.assertEqual(output, 'a,b,c\n1,2,3\n0,5,6\n')
+        self.assertEqual(output, 'a,b,c\n1,2.0,3.0\n0,5.0,6.0\n')
 
     def test_no_prefix_unique_constraint(self):
         self.get_output(['--db', 'sqlite:///' + self.db_file, '--insert', 'examples/dummy.csv', '--unique-constraint', 'a'])
