@@ -47,6 +47,18 @@ class TestIn2CSV(CSVKitTestCase, EmptyFileTests):
     def test_date_format(self):
         self.assertConverted('csv', 'examples/test_date_format.csv', 'examples/test_date_format_converted.csv', ['--date-format', '%d/%m/%Y'])
 
+    def test_date_format_default(self):
+        self.assertConverted('csv', 'examples/test_date_format.csv', 'examples/test_date_format.csv')
+
+    def test_numeric_date_format(self):
+        self.assertConverted('csv', 'examples/test_numeric_date_format.csv', 'examples/test_date_format_converted.csv', ['--date-format', '%Y%m%d'])
+
+    def test_numeric_date_format_default(self):
+        self.assertConverted('csv', 'examples/test_numeric_date_format.csv', 'examples/test_numeric_date_format.csv')
+
+    def test_date_like_number(self):
+        self.assertConverted('csv', 'examples/date_like_number.csv', 'examples/date_like_number.csv')
+
     def test_convert_csv(self):
         self.assertConverted('csv', 'examples/testfixed_converted.csv', 'examples/testfixed_converted.csv')
 
@@ -104,6 +116,13 @@ class TestIn2CSV(CSVKitTestCase, EmptyFileTests):
     def test_convert_xlsx_with_skip_lines(self):
         self.assertConverted('xlsx', 'examples/test_skip_lines.xlsx', 'examples/testxlsx_converted.csv', ['--skip-lines', '3'])
 
+    def test_names(self):
+        self.assertLines(['--names', 'examples/sheets.xlsx'], [
+            'not this one',
+            'data',
+            u'ʤ',
+        ])
+
     def test_csv_no_headers(self):
         self.assertConverted('csv', 'examples/no_header_row.csv', 'examples/dummy.csv', ['--no-header-row', '--no-inference'])
 
